# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt

class UserNotificationSettingsResponse(BaseModel):
    """
    UserNotificationSettingsResponse
    """
    id: Optional[StrictInt] = None
    user_id: StrictInt = Field(...)
    receive_email_notifications: Optional[StrictBool] = False
    receive_in_app_notifications: Optional[StrictBool] = True
    __properties = ["id", "user_id", "receive_email_notifications", "receive_in_app_notifications"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserNotificationSettingsResponse:
        """Create an instance of UserNotificationSettingsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserNotificationSettingsResponse:
        """Create an instance of UserNotificationSettingsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserNotificationSettingsResponse.parse_obj(obj)

        _obj = UserNotificationSettingsResponse.parse_obj({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "receive_email_notifications": obj.get("receive_email_notifications") if obj.get("receive_email_notifications") is not None else False,
            "receive_in_app_notifications": obj.get("receive_in_app_notifications") if obj.get("receive_in_app_notifications") is not None else True
        })
        return _obj





# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector.api.templates_api import TemplatesApi  # noqa: E501


class TestTemplatesApi(unittest.IsolatedAsyncioTestCase):
    """TemplatesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TemplatesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_templates_delete_portal_override(self) -> None:
        """Test case for templates_delete_portal_override

        Delete override  # noqa: E501
        """
        pass

    async def test_templates_get_contact_footer(self) -> None:
        """Test case for templates_get_contact_footer

        Get contact info footer  # noqa: E501
        """
        pass

    async def test_templates_get_overridable_source_types(self) -> None:
        """Test case for templates_get_overridable_source_types

        Get all overridable source types  # noqa: E501
        """
        pass

    async def test_templates_get_portal_template(self) -> None:
        """Test case for templates_get_portal_template

        Get specific template for portal  # noqa: E501
        """
        pass

    async def test_templates_get_portal_templates(self) -> None:
        """Test case for templates_get_portal_templates

        Get all templates for portal  # noqa: E501
        """
        pass

    async def test_templates_get_templates(self) -> None:
        """Test case for templates_get_templates

        Get raw templates  # noqa: E501
        """
        pass

    async def test_templates_reset_contact_footer(self) -> None:
        """Test case for templates_reset_contact_footer

        Reset contact info footer  # noqa: E501
        """
        pass

    async def test_templates_upsert_contact_footer(self) -> None:
        """Test case for templates_upsert_contact_footer

        Set contact info footer  # noqa: E501
        """
        pass

    async def test_templates_upsert_portal_override(self) -> None:
        """Test case for templates_upsert_portal_override

        Create or update override  # noqa: E501
        """
        pass

    async def test_templates_upsert_portal_overrides_batch(self) -> None:
        """Test case for templates_upsert_portal_overrides_batch

        Batch create or update overrides  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
